/**
 * tdesign v1.12.1
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _baseGet = require('./dep-8bc1cdb3.js');
var isArguments = require('./dep-93691cd7.js');
var isArray = require('./dep-24d4266a.js');
var _isIndex = require('./dep-39cfa1e8.js');
var isArrayLike = require('./dep-d5965f49.js');

/**
 * Checks if `path` exists on `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @param {Function} hasFunc The function to check properties.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 */
function hasPath(object, path, hasFunc) {
  path = _baseGet.castPath(path, object);
  var index = -1,
    length = path.length,
    result = false;
  while (++index < length) {
    var key = _baseGet.toKey(path[index]);
    if (!(result = object != null && hasFunc(object, key))) {
      break;
    }
    object = object[key];
  }
  if (result || ++index != length) {
    return result;
  }
  length = object == null ? 0 : object.length;
  return !!length && isArrayLike.isLength(length) && _isIndex.isIndex(key, length) && (isArray.isArray(object) || isArguments.isArguments(object));
}

exports.hasPath = hasPath;
//# sourceMappingURL=dep-199b9155.js.map
