/**
 * tdesign v1.12.1
 * (c) 2025 tdesign
 * @license MIT
 */

import { _ as _defineProperty } from '../_chunks/dep-f105ca38.js';
import { _ as _objectWithoutProperties } from '../_chunks/dep-5462fae6.js';
import React, { forwardRef, useContext } from 'react';
import classNames from 'classnames';
import { isObject } from 'lodash-es';
import useConfig from '../hooks/useConfig.js';
import { colDefaultProps } from './defaultProps.js';
import { RowContext } from './Row.js';
import useDefaultProps from '../hooks/useDefaultProps.js';
import '../_chunks/dep-bff1a51f.js';
import '../config-provider/ConfigContext.js';
import '../locale/zh_CN.js';
import '../_chunks/dep-e61f9018.js';
import 'dayjs';
import '../_chunks/dep-3c66615e.js';
import '../_chunks/dep-4501cb83.js';
import '../_chunks/dep-34d8fc80.js';
import '../_chunks/dep-4fb528b6.js';

var _excluded = ["flex", "offset", "order", "pull", "push", "span", "tag", "className", "children", "style"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var calcColPadding = function calcColPadding(gutter, currentSize) {
  var paddingObj = {};
  if (typeof gutter === "number") {
    Object.assign(paddingObj, {
      paddingLeft: "".concat(gutter / 2, "px"),
      paddingRight: "".concat(gutter / 2, "px")
    });
  } else if (Array.isArray(gutter) && gutter.length) {
    if (typeof gutter[0] === "number") {
      Object.assign(paddingObj, {
        paddingLeft: "".concat(gutter[0] / 2, "px"),
        paddingRight: "".concat(gutter[0] / 2, "px")
      });
    }
    if (isObject(gutter[0]) && gutter[0][currentSize]) {
      Object.assign(paddingObj, {
        paddingLeft: "".concat(gutter[0][currentSize] / 2, "px"),
        paddingRight: "".concat(gutter[0][currentSize] / 2, "px")
      });
    }
  } else if (isObject(gutter) && gutter[currentSize]) {
    Object.assign(paddingObj, {
      paddingLeft: "".concat(gutter[currentSize] / 2, "px"),
      paddingRight: "".concat(gutter[currentSize] / 2, "px")
    });
  }
  return paddingObj;
};
var parseFlex = function parseFlex(flex) {
  if (typeof flex === "number") {
    return "".concat(flex, " ").concat(flex, " auto");
  }
  if (/^\d+(\.\d+)?(px|r?em|%)$/.test(flex)) {
    return "0 0 ".concat(flex);
  }
  return flex;
};
var Col = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useDefaultProps = useDefaultProps(props, colDefaultProps),
    flex = _useDefaultProps.flex,
    offset = _useDefaultProps.offset,
    order = _useDefaultProps.order,
    pull = _useDefaultProps.pull,
    push = _useDefaultProps.push,
    span = _useDefaultProps.span,
    tag = _useDefaultProps.tag,
    className = _useDefaultProps.className,
    children = _useDefaultProps.children,
    propStyle = _useDefaultProps.style,
    otherColProps = _objectWithoutProperties(_useDefaultProps, _excluded);
  var _useContext = useContext(RowContext),
    rowGutter = _useContext.gutter,
    rowSize = _useContext.size;
  var _useConfig = useConfig(),
    classPrefix = _useConfig.classPrefix;
  var allSizes = ["xs", "sm", "md", "lg", "xl", "xxl"];
  var sizeClasses = allSizes.reduce(function (acc, currSize) {
    var sizeProp = props[currSize];
    var sizeObj = {};
    if (typeof sizeProp === "number") {
      sizeObj.span = sizeProp;
    } else if (isObject(sizeProp)) {
      sizeObj = sizeProp || {};
    }
    return _objectSpread(_objectSpread({}, acc), {}, _defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({}, "".concat(classPrefix, "-col-").concat(currSize, "-").concat(sizeObj.span), sizeObj.span !== void 0), "".concat(classPrefix, "-col-").concat(currSize, "-order-").concat(sizeObj.order), parseInt(sizeObj.order, 10) >= 0), "".concat(classPrefix, "-col-").concat(currSize, "-offset-").concat(sizeObj.offset), parseInt(sizeObj.offset, 10) >= 0), "".concat(classPrefix, "-col-").concat(currSize, "-push-").concat(sizeObj.push), parseInt(sizeObj.push, 10) >= 0), "".concat(classPrefix, "-col-").concat(currSize, "-pull-").concat(sizeObj.pull), parseInt(sizeObj.pull, 10) >= 0));
  }, {});
  var colClassNames = classNames("".concat(classPrefix, "-col"), className, _defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({}, "".concat(classPrefix, "-col-").concat(span), span !== void 0), "".concat(classPrefix, "-col-offset-").concat(offset), parseInt(offset, 10) >= 0), "".concat(classPrefix, "-col-pull-").concat(pull), parseInt(pull, 10) >= 0), "".concat(classPrefix, "-col-push-").concat(push), parseInt(push, 10) >= 0), "".concat(classPrefix, "-col-order-").concat(order), parseInt(order, 10) >= 0), sizeClasses);
  var colStyle = _objectSpread(_objectSpread({}, calcColPadding(rowGutter, rowSize)), propStyle);
  flex && (colStyle.flex = parseFlex(flex));
  return /*#__PURE__*/React.createElement(tag, _objectSpread({
    ref: ref,
    className: colClassNames,
    style: colStyle
  }, otherColProps), children);
});
Col.displayName = "Col";

export { Col as default };
//# sourceMappingURL=Col.js.map
